@@ -1,5 +1,5 @@
 /*
- * $Id: cap_alloc.c,v 1.1.1.1 1999/04/17 22:16:31 morgan Exp $
+ * $Id: cap_alloc.c,v 1.1.1.1.2.1 1999/04/23 06:16:31 morgan Exp $
  *
  * Copyright (c) 1997-8 Andrew G Morgan <morgan@linux.kernel.org>
  *
@@ -68,8 +68,13 @@ cap_t cap_init(void)
     cap_t result = (cap_t) calloc( 1, sizeof(*result) );
 
     if (result) {
+
 	result->magic = CAP_T_MAGIC;
-	result->head.version = _LINUX_CAPABILITY_VERSION;
+
+	_libcap_establish_api();
+	result->features = _libcap_kernel_features;
+	result->head.version = _libcap_kernel_version;
+
     } else {
 	errno = ENOMEM;
     }
@@ -78,6 +83,9 @@ cap_t cap_init(void)
 
 /*
  * $Log: cap_alloc.c,v $
+ * Revision 1.1.1.1.2.1  1999/04/23 06:16:31  morgan
+ * added support for revised kernel interface (with file cap support)
+ *
  * Revision 1.1.1.1  1999/04/17 22:16:31  morgan
  * release 1.0 of libcap
  *
