@@ -5,7 +5,7 @@
  * Copyright (C) 1997   Aleph One
  * Copyright (C) 1997-8 Andrew G. Morgan <morgan@linux.kernel.org>
  *
- * defunct POSIX.1e Standard: 25.2 Capabilities           <sys/capability.h>
+ * POSIX.1e Standard: 25.2 Capabilities                 <sys/capability.h>
  */
 
 #ifndef _SYS_CAPABILITY_H
@@ -20,7 +20,6 @@ extern "C" {
  * information for the user library.
  */
 
-#include <sys/types.h>
 #include <linux/capability.h>
 
 /*
@@ -64,7 +63,7 @@ typedef enum {
 
 /* libcap/cap_alloc.c */
 cap_t   cap_dup(cap_t);
-int     cap_free(void *);
+int     cap_free(cap_t *);
 cap_t   cap_init(void);
 
 /* libcap/cap_flag.c */
